#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-smallcheck
version:              0.5.2
visibility:           public
id:                   hspec-smallcheck-0.5.2-Gz7WWtGxrG8Io29Q8M8LBW
key:                  hspec-smallcheck-0.5.2-Gz7WWtGxrG8Io29Q8M8LBW
license:              MIT
copyright:            (c) 2013-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             http://hspec.github.io/
synopsis:             SmallCheck support for the Hspec testing framework
description:          SmallCheck support for the Hspec testing framework
category:             Testing
abi:                  fb0a8f32b841d00cdf1d692e06195f89
exposed:              True
exposed-modules:      Test.Hspec.SmallCheck
hidden-modules:
    Test.Hspec.SmallCheck.Compat Test.Hspec.SmallCheck.Types
    Paths_hspec_smallcheck

import-dirs:          /usr/lib/ghc-8.10.5/site-local/hspec-smallcheck-0.5.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hspec-smallcheck-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/hspec-smallcheck-0.5.2
hs-libraries:         HShspec-smallcheck-0.5.2-Gz7WWtGxrG8Io29Q8M8LBW
depends:
    HUnit-1.6.2.0-8FsjWfKzSV74wDnwnuEJe4 base-4.14.2.0
    call-stack-0.3.0-HaJG5jRa2XM74od97nDj56
    hspec-core-2.8.2-KLUu39SDCkuHXBcAtSZ1N9
    smallcheck-1.2.1-Cpn9B07vHfB1r0zOWeWxAg

haddock-interfaces:
    /usr/share/doc/haskell-hspec-smallcheck/html/hspec-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-hspec-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

